import * as nodeRedis from "redis";
import { Commands } from "../generated/interface";
import { Push } from "../push";
export declare type CommandResult<K extends keyof Commands> = ReturnType<Commands[K]> extends Promise<infer X> ? X : never;
/**
 * types from multis depend on a bunch of type inference so in IDEs they can end up looking like:
 * ```
 * Push<Push<Push<[], string>, "OK">, string[]>
 * ```
 *
 * This makes them appear as
 * ```
 * [string, "OK", string[]]
 * ```
 *
 * Taken from https://github.com/sindresorhus/type-fest/pull/157
 */
export declare type Simplify<T> = {
    [K in keyof T]: T[K];
};
export declare const WrappedNodeRedisMultiImpl: {
    new (multi: nodeRedis.Multi): {
        readonly nodeRedisMulti: nodeRedis.Multi;
        readonly exec: WrappedNodeRedisMulti["exec"];
        readonly exec_atomic: WrappedNodeRedisMulti["exec_atomic"];
    };
    create(multi: nodeRedis.Multi): WrappedNodeRedisMulti;
};
export declare type MultiCommands = Exclude<keyof Commands, "exec" | "exec_atomic">;
export declare type WrappedNodeRedisMulti<Results extends unknown[] = [
]> = {
    [K in MultiCommands]: (...args: Parameters<Commands[K]>) => WrappedNodeRedisMulti<Push<Results, CommandResult<K> | nodeRedis.ReplyError>>;
} & {
    exec: () => Promise<Results>;
    exec_atomic: () => Promise<Results>;
};
